Coverage report

# Coverage report: 69%

Hot-keys on this page

n s m x c change column sorting

Module | statements | missing | excluded | coverage
--- | --- | --- | --- | ---
Total | 1038 | 322 | 0 | 69%
jsanctions/__init__.py | 1 | 0 | 0 | 100%
jsanctions/admin.py | 185 | 113 | 0 | 39%
jsanctions/apps.py | 5 | 0 | 0 | 100%
jsanctions/eu.py | 104 | 27 | 0 | 74%
jsanctions/helpers.py | 22 | 0 | 0 | 100%
jsanctions/locale/__init__.py | 1 | 0 | 0 | 100%
jsanctions/locale/en/LC_MESSAGES/__init__.py | 1 | 0 | 0 | 100%
jsanctions/locale/en/__init__.py | 1 | 0 | 0 | 100%
jsanctions/locale/fi/LC_MESSAGES/__init__.py | 1 | 0 | 0 | 100%
jsanctions/locale/fi/__init__.py | 1 | 0 | 0 | 100%
jsanctions/management/__init__.py | 0 | 0 | 0 | 100%
jsanctions/management/commands/__init__.py | 0 | 0 | 0 | 100%
jsanctions/management/commands/import_eu_sanctions.py | 39 | 39 | 0 | 0%
jsanctions/management/commands/import_ofac_sanctions.py | 48 | 48 | 0 | 0%
jsanctions/management/commands/import_un_sanctions.py | 48 | 48 | 0 | 0%
jsanctions/models.py | 221 | 16 | 0 | 93%
jsanctions/ofac.py | 162 | 8 | 0 | 95%
jsanctions/services.py | 15 | 15 | 0 | 0%
jsanctions/tests.py | 29 | 0 | 0 | 100%
jsanctions/un.py | 142 | 6 | 0 | 96%
jsanctions/views.py | 0 | 0 | 0 | 100%
manage.py | 12 | 2 | 0 | 83%

No items found using the specified filter.